@@ -366,6 +366,7 @@ create_screen_widgets (struct ScreenInfo *screen_info, int nr, gboolean no_heade
   GtkWidget *table;
   GtkWidget *label;
   GtkWidget *option_menu;
+  GtkWidget *ret;
   char *str;
 
   table = gtk_table_new (2, 2, FALSE);
@@ -416,9 +417,9 @@ create_screen_widgets (struct ScreenInfo *screen_info, int nr, gboolean no_heade
     str = g_strdup (_("Default Settings"));
   else
     str = g_strdup_printf (_("Screen %d Settings\n"), nr+1);
-  return wrap_in_label (table, str);
-  
+  ret = wrap_in_label (table, str);
   g_free (str);
+  return ret;
 }
 
 
@@ -472,7 +473,7 @@ create_dialog (struct DisplayInfo *info)
       strcmp (hostname, "localhost.localdomain") != 0)
     {
       
-      str = g_strdup_printf (_("Make default for this _computer (%s) only"), hostname);
+      str = g_strdup_printf (_("_Make default for this computer (%s) only"), hostname);
       per_computer_check = gtk_check_button_new_with_mnemonic (str);
 
       /* If we previously set the resolution specifically for this hostname, default
@@ -511,7 +512,7 @@ struct TimeoutData {
 char *
 timeout_string (int time)
 {
-  return g_strdup_printf (_("Testing the new settings. If you don't respond in %d seconds the previous settings will be restored."), time);
+  return g_strdup_printf (ngettext ("Testing the new settings. If you don't respond in %d second the previous settings will be restored.", "Testing the new settings. If you don't respond in %d seconds the previous settings will be restored.", time), time);
 }
 
 gboolean
